import logging
import urllib.parse
import datetime
import json

import requests
import pyjq

import abobjs

class AB_User(abobjs.AB_Base):

    """
    A.K.A. Cycles. Not Sure why the mismatch exists
    """

    _endpoint = "/api/v1/users"
    _single = ".users[0]"
    _name = "user"

    _uid_field = "username"

    _name_field = "email"

    def __init__(self, id=None, api_info=None, **kwargs):

        #self.api_info = api_info
        #self.id = control_id
        #self.datum = kwargs.get("control_datum", dict())

        # Dunder Handling
        endpoint = kwargs.get("endpoint", self._endpoint)
        single = kwargs.get("single", self._single)
        name = kwargs.get("name", self._name)

        #print(self._strips)
        #strips = kwargs.get("strips", self._strips)

        abobjs.AB_Base.__init__(self, id=id, api_info=api_info,
                                endpoint=endpoint, single=single, name=name,
                                **kwargs)


#!/usr/bin/env python3

import logging
import urllib.parse
import datetime
import json

import requests
import pyjq
import urllib.parse

import abobjs

def fn_register_custom_fields(api_info=None):

    """
    Should Iterate through the Custom Fields And Register their select & multiselect maps in SUBOBJ_LNK
    """

    logger = logging.getLogger("fn_register_custom_fields")

    all_custom_fields = abobjs.AB_Multi(type=abobjs.AB_Custom_Fields, api_info=api_info)

    logger.debug(all_custom_fields.multidatum)

    for x in all_custom_fields.multidatum:
        logger.debug(x.datum)

        if x.datum["type"] in ("Multiselect", "Select"):
            # Add to Map
            abobjs.SUBOBJ_LK[x.datum["attr_key"]] = {"map": x.datum["custom_field_options_map"]}

    logger.debug(abobjs.SUBOBJ_LK)






#!/usr/bin/env python3

import logging
import urllib.parse
import datetime
import json

import requests
import pyjq
import urllib.parse

import abobjs

class AB_Custom_Fields(abobjs.AB_Base):

    _endpoint = "/api/v1/custom_fields"
    _single = ".custom_fields[0]"
    _name = "custom_field"
    _get_params = {"include[]": "customFieldOptions"}
    _search_params = {"filter[deleted_at]": ""}

    _stich_def = [
        {"source": "custom_field_options",
         "idfield": "id",
         "val": "name",
         "isjqval": False}
    ]

    def __init__(self, id=None, api_info=None, **kwargs):

        # Dunder Handling
        endpoint = kwargs.get("endpoint", self._endpoint)
        single = kwargs.get("single", self._single)
        name = kwargs.get("name", self._name)

        abobjs.AB_Base.__init__(self, id=id, api_info=api_info,
                                endpoint=endpoint, single=single, name=name,
                                **kwargs)

